@@ -5,6 +5,7 @@ from collections import defaultdict
 from waypoint import WaypointClient
 from waypoint.models import StatHistory, GameRound, Stat
 from waypoint.data import map_ids
+from waypoint.enum import Game, GameVariant
 
 
 class RoundMapper:
@@ -16,13 +17,21 @@ class RoundMapper:
         ts = stat.DateTime.replace(second=0, microsecond=0).timestamp()
         return hashlib.md5(f"{ts}{stat.MapId}".encode("utf-8")).hexdigest()
 
-    def map_rounds(self, gamertags: List[str]) -> List[GameRound]:
+    def map_rounds(
+        self,
+        gamertags: List[str],
+        variant: GameVariant = GameVariant.SLAYER,
+        game: Game = Game.ALL,
+    ) -> List[GameRound]:
         round_map = defaultdict(dict)
         win_map = {}
         map_map = {}
         for page_num in range(1, 11):
             history: List[StatHistory] = self.client.get_game_history(
-                gamertags, page=page_num
+                gamertags,
+                variant,
+                game,
+                page_num,
             )
             for player_history in history:
                 for game in player_history.Stats:
@@ -40,10 +49,10 @@ class RoundMapper:
                 GameRound(
                     id=uid,
                     Participants=list(game_round.keys()),
-                    Winner=win_map.get(uid, "N/A"),
+                    Winner=win_map.get(uid),
                     PlayerStats=game_round,
-                    Map=map_info.get("map", "N/A"),
-                    Game=map_info.get("game", "N/A"),
+                    Map=map_info.get("map"),
+                    Game=map_info.get("game"),
                 )
             )
         return results
